==> EspoCRM-1.2.1.zip: EspoCRM-1.2.1/application/Espo/ORM/DB/MysqlMapper.php <==
<?php
/************************************************************************
 * This file is part of EspoCRM.
 *
 * EspoCRM - Open Source CRM application.
 * Copyright (C) 2014  Yuri Kuznetsov, Taras Machyshyn, Oleksiy Avramenko
 * Website: http://www.espocrm.com
 *
 * EspoCRM is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * EspoCRM is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with EspoCRM. If not, see http://www.gnu.org/licenses/.
 ************************************************************************/

namespace Espo\ORM\DB;

use Espo\ORM\Entity;
use Espo\ORM\Classes\EntityCollection;
use PDO;

/**
 * Abstraction for MySQL DB.
 * Mapping of Entity to DB.
 * Should be used internally only.
 */
class MysqlMapper extends Mapper
{
	protected function composeSelectQuery($table, $select, $joins = '', $where = '', $order = '', $offset = null, $limit = null, $distinct = null, $aggregation = false)
	{
		$sql = "SELECT";

		/*if (!empty($distinct)) {
			$sql .= " DISTINCT";
		}*/

		$sql .= " {$select} FROM `{$table}`";

		if (!empty($joins)) {
			$sql .= " {$joins}";
		}

		if (!empty($where)) {
			$sql .= " WHERE {$where}";
		}

		if (!empty($distinct)) {
			$sql .= " GROUP BY `{$table}`.id";
		}

		if (!empty($order)) {
			$sql .= " {$order}";
		}

		if (is_null($offset) && !is_null($limit)) {
			$offset = 0;
		}

		if (!is_null($offset) && !is_null($limit)) {
			$offset = intval($offset);
			$limit = intval($limit);
			$sql .= " LIMIT {$offset}, {$limit}";
		}

		return $sql;
	}

	protected function toDb($field)
	{
		if (array_key_exists($field, $this->fieldsMapCache)) {
			return $this->fieldsMapCache[$field];

		} else {
			$field[0] = strtolower($field[0]);
			$dbField = preg_replace_callback('/([A-Z])/', array($this, 'toDbConversion'), $field);

			$this->fieldsMapCache[$field] = $dbField;
			return $dbField;
		}
	}

	protected function toDbConversion($matches)
	{
		return "_" . strtolower($matches[1]);
	}
}
?>

==> EspoCRM-4.0.2.zip: EspoCRM-4.0.2/application/Espo/ORM/DB/MysqlMapper.php <==
<?php
/************************************************************************
 * This file is part of EspoCRM.
 *
 * EspoCRM - Open Source CRM application.
 * Copyright (C) 2014-2015 Yuri Kuznetsov, Taras Machyshyn, Oleksiy Avramenko
 * Website: http://www.espocrm.com
 *
 * EspoCRM is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * EspoCRM is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with EspoCRM. If not, see http://www.gnu.org/licenses/.
 *
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU General Public License version 3.
 *
 * In accordance with Section 7(b) of the GNU General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "EspoCRM" word.
 ************************************************************************/

namespace Espo\ORM\DB;
use Espo\ORM\Entity;
use Espo\ORM\Classes\EntityCollection;
use PDO;

/**
 * Abstraction for MySQL DB.
 * Mapping of Entity to DB.
 * Should be used internally only.
 */
class MysqlMapper extends Mapper
{
    protected function toDb($field)
    {
        return $this->query->toDb($field);
    }

}
